"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generator = void 0;
const chalk_1 = __importDefault(require("chalk"));
const generator = (node) => {
    switch (node.type) {
        case 'root':
            return node.children
                .map((child) => exports.generator(child))
                .join('\n');
        case 'link':
        case 'strong':
        case 'emphasis':
        case 'heading':
            return node.children
                .map((child) => exports.generator(child))
                .join(' ');
        case 'paragraph':
            return (node.children.map((child) => exports.generator(child)).join(' ') +
                '\n');
        case 'blockquote':
            return node.children
                .map((child) => exports.generator(child))
                .join('\n');
        case 'list':
            let returnNode;
            if (node.ordered) {
                returnNode = node.children.map((child, index) => {
                    let numberIndicator = chalk_1.default.bold.gray(index + 1 + '.');
                    return `${numberIndicator} ` + exports.generator(child);
                });
            }
            else {
                returnNode = node.children.map((child) => `${chalk_1.default.bold.gray('-')} ` + exports.generator(child));
            }
            return returnNode.join('');
        case 'listItem':
            return node.children
                .map((child) => {
                if (child.type === 'list') {
                    child.tabed = true;
                    return '    ' + exports.generator(child);
                }
                else {
                    if (child.tabed) {
                        child.tabed = true;
                        return '    ' + exports.generator(child);
                    }
                    else {
                        return exports.generator(child);
                    }
                }
            })
                .join('');
        case 'image':
        case 'thematicBreak':
        case 'code':
        case 'text':
            return node.value;
        default:
            return '';
    }
};
exports.generator = generator;
