"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformer = void 0;
const chalk_1 = __importDefault(require("chalk"));
const terminal_link_1 = __importDefault(require("terminal-link"));
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const utils_1 = require("./utils");
const cardinal_1 = __importDefault(require("cardinal"));
const transformer = (mdast) => __awaiter(void 0, void 0, void 0, function* () {
    unist_util_visit_1.default(mdast, (node, _, parent) => {
        if (node.type === 'paragraph') {
            switch (parent.type) {
                case 'blockquote':
                    node.kind = 'blockquote';
                    break;
                case 'listItem':
                    node.kind = 'listItem';
                    break;
            }
        }
        if (node.type === 'text') {
            switch (parent.type) {
                case 'heading':
                    node.value += '\n';
                    switch (parent.depth) {
                        case 1:
                            node.value = chalk_1.default.bold.underline.red(node.value);
                            break;
                        case 2:
                            node.value = chalk_1.default.cyan.hex('#e78a4e').bold(node.value);
                            break;
                        case 3:
                            node.value = chalk_1.default.yellow.bold(node.value);
                            break;
                        case 4:
                            node.value = chalk_1.default.green.bold(node.value);
                            break;
                        case 5:
                            node.value = chalk_1.default.blue.bold(node.value);
                            break;
                        case 6:
                            node.value = chalk_1.default.magenta.bold(node.value);
                            break;
                    }
                    break;
                case 'link':
                    const link = terminal_link_1.default(node.value, parent.url);
                    node.value = chalk_1.default.blue(link);
                    break;
                case 'emphasis':
                    node.value = chalk_1.default.italic(node.value);
                    break;
                case 'strong':
                    node.value = chalk_1.default.bold(node.value);
                    break;
                case 'paragraph':
                    switch (parent.kind) {
                        case 'blockquote':
                            node.value = '┃ ' + chalk_1.default.gray.italic(node.value);
                            break;
                        case 'listItem':
                            node.value = chalk_1.default.reset(node.value);
                            break;
                    }
            }
        }
        switch (node.type) {
            case 'image':
                const link = terminal_link_1.default(node.alt, node.url);
                node.value = chalk_1.default.gray.italic(`Image: ${link}`);
                break;
            case 'inlineCode':
                node.value = chalk_1.default.yellow(node.value);
                node.type = 'text';
                break;
            case 'thematicBreak':
                node.value = chalk_1.default.reset('_'.repeat(process.stdout.columns) + '\n');
                break;
            case 'code':
                const codeLang = node.lang ? chalk_1.default.gray('// ' + node.lang + '\n') : '';
                node.value += '\n';
                if (node.lang === 'ts' || node.lang === 'js' || node.lang === 'json') {
                    node.value = cardinal_1.default.highlight(node.value);
                }
                else {
                    node.value = chalk_1.default.gray(node.value);
                }
                node.value = codeLang + node.value;
                break;
        }
        if (node.type === 'text') {
            if (utils_1.isMarkdownTable(node.value)) {
                node.value = utils_1.prettifyTable(node.value);
            }
        }
    });
});
exports.transformer = transformer;
